#######################################################################
#
#    dream Notifications for Enigma2
#    by Christian Fees
#
#######################################################################

from Screens.Screen import Screen
from Components.Label import Label
from Components.ScrollLabel import ScrollLabel
from Components.Pixmap import Pixmap
from Components.AVSwitch import AVSwitch
from Components.ActionMap import ActionMap
from Plugins.Plugin import PluginDescriptor
from enigma import ePicLoad,eTimer,ePoint, eSize
from skin import parseColor
###########################################################################

class NotificationScreen(Screen):

	def __init__(self, session, picPath = None, title = "Title", message = "Message", timeout = 7, x = 900, y = 500, bkgColor = "#22607d8b", skn = ""):
		self.skin = skn
		Screen.__init__(self, session)
		print "[dream Notifications] NotificationScreen init"
		self.picPath = picPath
		self["icon"] = Pixmap()
		label = Label()
		self["title"] = label
		if self["title"] is not None:
			self["title"].setText( title )
		label = Label()
		self["msg"] = label
		if self["msg"] is not None:
			self["msg"].setText( message )
		
		self["actionMap"] = ActionMap(["SetupActions"],
		{
			"ok": self.cancel,
			"cancel": self.cancel
		}, -1)
		self.initTimeout(timeout)
		self.onLayoutFinish.append(self.ShowPicture)

	def ShowPicture(self):
		self.onLayoutFinish.remove(self.ShowPicture)
		if self.picPath is not None:
			self["icon"].instance.setPixmapFromFile("/tmp/logo.png")
			

	def cancel(self):
		print "[dream Notifications] NotificationScreen cancel"
		self.close(None)
		

	def initTimeout(self, timeout):
		self.timeout = timeout
		if timeout > 0:
			self.timer = eTimer()
			try:
				self.timer.callback.append(self.timerTick)
			except:
				self.timer_conn = self.timer.timeout.connect(self.timerTick)
			self.onExecBegin.append(self.startTimer)
			if self.execing:
				self.timerTick()
			else:
				self.onShown.append(self.__onShown)
			self.timerRunning = True
		else:
			self.timerRunning = False

	def startTimer(self):
		self.timer.start(1000)

	def stopTimer(self):
		if self.timerRunning:
			del self.timer
			self.onExecBegin.remove(self.startTimer)
			self.timerRunning = False
			
	def timeoutCallback(self):
		self.cancel()
		
	def timerTick(self):
		if self.execing:
			self.timeout -= 1
			if self.timeout == 0:
				self.timer.stop()
				self.timerRunning = False
				self.timeoutCallback()

	def __onShown(self):
		self.onShown.remove(self.__onShown)
		self.timerTick()